@@ -1,5 +1,5 @@
 /*
- * $Id: ngrep.h,v 1.11 1999/10/13 17:04:07 jpr5 Exp $
+ * $Id: ngrep.h,v 1.13 2000/02/01 12:28:08 jpr5 Exp $
  *
  */
 
@@ -10,6 +10,7 @@
 #define SLIPHDR_SIZE 16
 #define RAWHDR_SIZE 0
 #define LOOPHDR_SIZE 4 
+#define FDDIHDR_SIZE 21
 
 #ifndef IP_OFFMASK
 #define IP_OFFMASK 0x1fff
@@ -20,9 +21,9 @@
 
 char *get_filter(char **);
 void process(u_char *, struct pcap_pkthdr*, u_char *);
-int re_match_func(struct re_pattern_buffer*, char *, int); 
-int blank_match_func(struct re_pattern_buffer*, char *, int); 
+int re_match_func(char *, int); 
+int blank_match_func(char *, int); 
 void dump(char *, int); 
-void dealloc(int);
+void clean_exit(int);
 void usage(int);
 void version(void);
